@@ -3,8 +3,11 @@
 ## Core functions for stability-validated aggregation
 ## =======================================================================
 
-
 ## ---- Utility Functions ----
+#' @importFrom stats complete.cases quantile median model.matrix setNames
+#' @importFrom graphics plot lines legend abline boxplot text par
+#' @importFrom utils txtProgressBar setTxtProgressBar
+NULL
 
 #' Read Excel file with fallback options
 #' @keywords internal
@@ -23,7 +26,6 @@
 to01 <- function(x) {
   if (is.logical(x)) return(as.integer(x))
   if (is.factor(x)) x <- as.character(x)
-
   
   if (is.character(x)) {
     x <- tolower(trimws(x))
@@ -183,7 +185,8 @@ print.mca_fit <- function(x, ...) {
 #' \donttest{
 #' # Using included ANR2 dataset
 #' data(ANR2)
-#' pa <- mca_pa(ANR2, vars = names(ANR2), B = 100)
+#' vars <- c("MDD", "DYS", "DEP", "PTSD", "OCD", "GAD", "ANX", "SOPH", "ADHD")
+#' pa <- mca_pa(ANR2, vars = vars, B = 100)
 #' print(pa$K_star)
 #' }
 mca_pa <- function(data, 
@@ -233,7 +236,7 @@ mca_pa <- function(data,
   
   # Determine retention
   eig_q <- apply(eig_perm, 2, quantile, probs = q, na.rm = TRUE)
-  K_star <- sum(eig_obs > eig_q)
+  K_star <- sum(round(eig_obs, 8) > round(eig_q, 8))
   
   # Create output object
   out <- structure(
@@ -376,7 +379,8 @@ mca_align <- function(G, Gref) {
 #' \donttest{
 #' # Using included ANR2 dataset
 #' data(ANR2)
-#' boot <- mca_bootstrap(ANR2, vars = names(ANR2), K = 3, B = 100)
+#' vars <- c("MDD", "DYS", "DEP", "PTSD", "OCD", "GAD", "ANX", "SOPH", "ADHD")
+#' boot <- mca_bootstrap(ANR2, vars = vars, K = 3, B = 100)
 #' print(boot)
 #' }
 mca_bootstrap <- function(data, 
@@ -602,7 +606,8 @@ summary.alsi <- function(object, ...) {
 #' @examples
 #' \donttest{
 #' data(ANR2)
-#' boot <- mca_bootstrap(ANR2, vars = names(ANR2), K = 3, B = 100)
+#' vars <- c("MDD", "DYS", "DEP", "PTSD", "OCD", "GAD", "ANX", "SOPH", "ADHD")
+#' boot <- mca_bootstrap(ANR2, vars = vars, K = 3, B = 100)
 #' plot_subspace_stability(boot)
 #' }
 plot_subspace_stability <- function(boot_obj) {
@@ -664,7 +669,8 @@ plot_subspace_stability <- function(boot_obj) {
 #' @examples
 #' \donttest{
 #' data(ANR2)
-#' pa <- mca_pa(ANR2, vars = names(ANR2), B = 100, verbose = FALSE)
+#' vars <- c("MDD", "DYS", "DEP", "PTSD", "OCD", "GAD", "ANX", "SOPH", "ADHD")
+#' pa <- mca_pa(ANR2, vars = vars, B = 100, verbose = FALSE)
 #' fit <- pa$fit
 #' plot_category_projections(fit, K = pa$K_star)
 #' }
@@ -729,7 +735,7 @@ plot_category_projections <- function(fit,
 #' Runs a complete ALSI analysis including parallel analysis for dimensionality
 #' assessment, bootstrap stability evaluation, ALSI computation, and visualization.
 #'
-#' @param path Path to data file (.xlsx) or data frame
+#' @param data Data frame or path to .xlsx file
 #' @param vars Character vector of binary variable names
 #' @param B_pa Number of permutations for parallel analysis (default: 2000)
 #' @param B_boot Number of bootstrap resamples (default: 2000)
@@ -746,21 +752,19 @@ plot_category_projections <- function(fit,
 #' @export
 #' @examples
 #' \donttest{
-#' # Complete workflow using included ANR2 dataset
 #' data(ANR2)
+#' vars <- c("MDD", "DYS", "DEP", "PTSD", "OCD", "GAD", "ANX", "SOPH", "ADHD")
 #' results <- alsi_workflow(
-#'   path = ANR2,
-#'   vars = names(ANR2),
-#'   B_pa = 100,
+#'   data   = ANR2,
+#'   vars   = vars,
+#'   B_pa   = 100,
 #'   B_boot = 100
 #' )
-#' 
-#' # Access components
-#' results$pa       # Parallel analysis
-#' results$boot     # Bootstrap stability
-#' results$alsi     # ALSI values
+#' results$pa
+#' results$boot
+#' results$alsi
 #' }
-alsi_workflow <- function(path,
+alsi_workflow <- function(data,
                           vars,
                           B_pa = 2000,
                           B_boot = 2000,
@@ -774,7 +778,7 @@ alsi_workflow <- function(path,
   # Step 1: Parallel analysis
   cat("Step 1: Parallel Analysis\n")
   cat("----------------------------------------\n")
-  pa <- mca_pa(path, vars, B = B_pa, q = q, seed = seed, verbose = TRUE)
+  pa <- mca_pa(data, vars, B = B_pa, q = q, seed = seed, verbose = TRUE)
   K <- pa$K_star
   
   cat("\n\n")
@@ -782,7 +786,7 @@ alsi_workflow <- function(path,
   # Step 2: Bootstrap stability
   cat("Step 2: Bootstrap Stability Assessment\n")
   cat("----------------------------------------\n")
-  boot <- mca_bootstrap(path, vars, K = K, B = B_boot, seed = seed, verbose = TRUE)
+  boot <- mca_bootstrap(data, vars, K = K, B = B_boot, seed = seed, verbose = TRUE)
   plot_subspace_stability(boot)
   
   cat("\n\n")
@@ -812,4 +816,4 @@ alsi_workflow <- function(path,
     alsi = alsi_obj,
     K = K
   ))
-}
+}
\ No newline at end of file
